\name{PENreg}
\alias{PENreg}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
  Penalized estimation with grid search of tunning parameters
}
\description{
  This function is a combination of penalized estimation and tunning parameters grid search. The penalized estimator is calculated for all candidates of tunning parameters. The choice of optimal tunning parameters is made based on the CIC criterion.
}
\usage{
PENreg(y, t, basis, dbasis, ddbasis, S, seedb, nknots, nboots)
}
\arguments{
  \item{y}{ a numeric vector of reponses.}
  \item{t}{ a numeric vector of normalized locations.}
  \item{basis}{ a numeric matrix of B-spline basis evaluation on all locations, "t".}
  \item{dbasis}{ a numeric matrix of the first derivative of B-spline basis on knots.}
  \item{ddbasis}{ a numeric matrix of the second derivative of B-spline basis on knots.}
  \item{S}{ a numeric matrix of all tunning parameters candidates for grid search.}
  \item{seedb}{ a numeric vector of seeds for involved bootstrap process to use.}
  \item{nknots}{ a numeric number indicating the amount of equally distributed knots in [0,1] interval.}
  \item{nboots}{ a number indicating the times in bootstrap procedure.}
}
\details{
  For each estimation given a candidate for tunning parameters, the calculation of CIC crieterion would invovle bootstrap process. For large amount of candidates, the running time would not be ignorable. This function has a progress track for the processing time.
}
\value{
%%  ~Describe the value returned
%%  If it is a LIST, use
  \item{s12.opt }{ a 2-dim vector including the optimal choice of tunning parameters for first and second derivatives such that CIC is smallest in all candidates. }
  \item{coef.cic.opt }{ a vecctor of penalized coefficients estimator based on optimal choice of tunning parameter, "s12.opt".}
  \item{CIC }{ a matrix of all CIC values and their corresponding tunning parameter candidates. }
  \item{weight}{ a 4-dim numeric vector of adaptive weights for penalty terms.}
  \item{yunpfit}{ a vector of unpenalized estimated response, which is used to generate the adaptive weights.}
}
\author{
  Zhikun Gao, Yanlin Tang, Judy Huixia Wang
}

\note{
  This CIC refers to Covariance Inflation Criterion (R. Tibshirani and K. Knight, 1999)
}

\references{
"Tibshirani, R. and Knight, K. (1999), The Covariance Inflation Criterion for Adaptive Model Selection. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 61: 529-546."
}
