\name{SCreg}
\alias{SCreg}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
 Shape-constrained regression
}
\description{
  The shape-constrained regression method provides a procedure that can simultaneously estimate regression curve and identify the shape of curve such as monotonicity and concavity. The identification of shape is achieved through penalization and parameter selection.
}
\usage{
SCreg(data, nknots, ngrid, tps, seedb, nboots)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{ a matrix of paired predictor and response, with first row being predictor and second row being response.}
  \item{nknots}{ a number of knots used to build B-spline basis.}
  \item{ngrid}{ a number of points (on each axis) used to build tunning parameters square grid.}
  \item{tps}{ a vector indicating the range of tunning parameters candidates during the searching.}
  \item{seedb}{ a vector of seeds used in the bootstrap process of selecting tunning parameters (for tracking and repeating estimation).}
  \item{nboots}{ a number of bootstrap repetition.}

}
\details{
  The shape-constained regression involves the using of B-spline expansion in the estimation part and shape identification is determined through penalization which covariance-inflation-criterion is applied with a bootstrap procedure. For the tuning parameters in the penalization, covariance-information-criterion is introduced to select an optimal choice from presetting candidates.

  The estimation part is a combination of B-spline expansion and quadratic programming, which is directly borrow from  "fda" and "quadprog" pakcages. The penalization and selection of tuning parameters is achieved through \link{PENreg}.
}
\value{
%%  ~Describe the value returned
%%  If it is a LIST, use
  \item{first.der }{ The penalized first derivatives estimation on the internal knots.}
  \item{second.der }{ The penalized second derivatives estimation on the internal knots.}
  \item{s12.opt }{ A 2-dim vector of the optimal choice of tunning parameters for first and second derivatives such that CIC is smallest in all candidates. }
  \item{coef.cic.opt }{ A numeric vector of the penalized B-spline basis coefficients chosen by CIC criterion. }
  \item{SCIC }{ A matrix of all tunning parameters candidates with corresponding CIC value.}
  \item{Sweight }{ A 4-dim numeric vector of adaptive weights for penalty terms.}
  \item{Sknots }{ A 4-dim numeric vector of adaptive weights for penalty terms.}
  \item{knots}{ A vector of location of knots used to build the S-spline basis.}
  \item{datafpen}{ A vector of penalized response estimation for give data based on optimal choice of tunning parameters.}
  \item{datafpen}{ A vector of unpenalized response estimation for give data.}
}
\references{
%% ~put references to the literature/web site here ~
}
\author{
  Zhikun Gao, Yanlin Tang, Judy Huixia Wang
}
\note{
  The quadratic B-spline is applied in the estimation. Since the second derivative of quadratic B-spline is not conitnuous on internal knots, the evaluation value is the right limit. This CIC refers to Covariance Inflation Criterion (R. Tibshirani and K. Knight, 1999). The "fda" and "quadprog" packages are required.

  Please also check the publication "Automatic Shape-constrained Regression, Gao et al."
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
    "fda" package: "https://cran.r-project.org/web/packages/fda/fda.pdf".

    "quadprog" package: "https://cran.r-project.org/web/packages/quadprog/quadprog.pdf"

    "Tibshirani, R. and Knight, K. (1999), The Covariance Inflation Criterion for Adaptive Model Selection. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 61: 529-546.
}
\examples{
### Load default example data in package

data = scregdata$syllable1

### Specify other arguments for SCreg function.

nknots <- 5
ngrid <- 6
tps <- c(0.1, 2, 0.1, 2)
seedb <- c(1:100000)
nboots <- 200

### Conduct shape constraint estimation,
### as well as tunning parameter selection.

result <- SCreg(data, nknots, ngrid, tps, seedb, nboots)

### Evaluate the first two derviatives at all knots.

der.knots.table <- cbind(round(result$first.der, 1), round(result$second.der, 1))
colnames(der.knots.table) <- c("first.der", "second.der")
der.knots.table

# By quadratic B-spline feature,
# The estimated curve is increasing and concave.

### Draw the plot of penalized estimated curve
### with comparison to unpenalized estimation

plot(x = data[1,], y = data[2,], xlab = "t", ylab = "y")
lines(x = data[1,], y = result$datafpen, lty = 1)
lines(x = data[1,], y = result$datafupen, lty = 2)

# From the plot, the points are the raw data.
# The real line is the penalized estimation curve.
# The dash line is the unpenalized estimation curve.

}

